==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Ul_/Ue_/Sl_/Sci_/RbahoppAlloc.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RbahoppAlloc:
	"""RbahoppAlloc commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rbahoppAlloc", core, parent)

	def set(self, rba_and_hopp_alloc: int, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:SCI<CH>:RBAHoppalloc \n
		Sets the DCI field resource block (RBA) and hopping resource allocation. This field identifies which resource blocks,
		within the subframes indicated by the time resource pattern ITRP, are used for PSSCH transmission. \n
			:param rba_and_hopp_alloc: integer Range: 0 to 8191
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sci')"""
		param = Conversions.decimal_value_to_str(rba_and_hopp_alloc)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{stream_cmd_val}:SL:SCI{channel_cmd_val}:RBAHoppalloc {param}')

	def get(self, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> int:
		"""[SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:SCI<CH>:RBAHoppalloc \n
		Sets the DCI field resource block (RBA) and hopping resource allocation. This field identifies which resource blocks,
		within the subframes indicated by the time resource pattern ITRP, are used for PSSCH transmission. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sci')
			:return: rba_and_hopp_alloc: integer Range: 0 to 8191"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{stream_cmd_val}:SL:SCI{channel_cmd_val}:RBAHoppalloc?')
		return Conversions.str_to_int(response)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Ul_/Ue_/Sl_/Sci_/RbahoppAlloc.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RbahoppAlloc:
	"""RbahoppAlloc commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rbahoppAlloc", core, parent)

	def set(self, rba_and_hopp_alloc: int, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:SCI<CH>:RBAHoppalloc \n
		Snippet: driver.source.bb.eutra.ul.ue.sl.sci.rbahoppAlloc.set(rba_and_hopp_alloc = 1, stream = repcap.Stream.Default, channel = repcap.Channel.Default) \n
		Sets the DCI field resource block (RBA) and hopping resource allocation. This field identifies which resource blocks,
		within the subframes indicated by the time resource pattern ITRP, are used for PSSCH transmission. \n
			:param rba_and_hopp_alloc: integer Range: 0 to 8191
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sci')"""
		param = Conversions.decimal_value_to_str(rba_and_hopp_alloc)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{stream_cmd_val}:SL:SCI{channel_cmd_val}:RBAHoppalloc {param}')

	def get(self, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:SCI<CH>:RBAHoppalloc \n
		Snippet: value: int = driver.source.bb.eutra.ul.ue.sl.sci.rbahoppAlloc.get(stream = repcap.Stream.Default, channel = repcap.Channel.Default) \n
		Sets the DCI field resource block (RBA) and hopping resource allocation. This field identifies which resource blocks,
		within the subframes indicated by the time resource pattern ITRP, are used for PSSCH transmission. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sci')
			:return: rba_and_hopp_alloc: integer Range: 0 to 8191"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{stream_cmd_val}:SL:SCI{channel_cmd_val}:RBAHoppalloc?')
		return Conversions.str_to_int(response)
